---
title: <span class="badge builder"></span> SimulationQuery
---
# <span class="badge builder"></span> SimulationQuery

## Constructor

```python
SimulationQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> testdata.SimulationQuery
```

### <span class="badge object-method"></span> config

```python
def config(config: dict[str, object]) -> typing.Self
```

### <span class="badge object-method"></span> key

```python
def key(key: cogbuilder.Builder[testdata.Key]) -> typing.Self
```

### <span class="badge object-method"></span> last

```python
def last(last: bool) -> typing.Self
```

### <span class="badge object-method"></span> stream

```python
def stream(stream: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [SimulationQuery](./object-SimulationQuery.md)
